# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/resource_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2
from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/cdn/v1/resource_service.proto',
  package='yandex.cloud.cdn.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/cdn/v1/resource_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/cdn/v1/origin.proto\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x12GetResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x14ListResourcesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListResourcesResponse\x12\x30\n\tresources\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.cdn.v1.Resource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdd\x04\n\x15\x43reateResourceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05\x63name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12G\n\x06origin\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.CreateResourceRequest.OriginB\x04\xe8\xc7\x31\x01\x12\x44\n\x13secondary_hostnames\x18\x04 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x07options\x18\x07 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12\x42\n\x0fssl_certificate\x18\x08 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\x1a\x99\x01\n\x06Origin\x12\x19\n\x0forigin_group_id\x18\x01 \x01(\x03H\x00\x12\x17\n\rorigin_source\x18\x02 \x01(\tH\x00\x12I\n\x14origin_source_params\x18\x03 \x01(\x0b\x32).yandex.cloud.cdn.v1.ResourceOriginParamsH\x00\x42\x10\n\x0eorigin_variant\"U\n\x14ResourceOriginParams\x12\x0e\n\x06source\x18\x01 \x01(\t\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yandex.cloud.cdn.v1.OriginMeta\";\n\x16\x43reateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x9b\x03\n\x15UpdateResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\x0forigin_group_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x13secondary_hostnames\x18\x03 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SecondaryHostnames\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12<\n\x0forigin_protocol\x18\x05 \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x0fssl_certificate\x18\x07 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLTargetCertificate\";\n\x16UpdateResourceMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x15\x44\x65leteResourceRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteResourceMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\":\n\x17GetProviderCNameRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x18GetProviderCNameResponse\x12\r\n\x05\x63name\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t2\x98\x07\n\x0fResourceService\x12v\n\x03Get\x12\'.yandex.cloud.cdn.v1.GetResourceRequest\x1a\x1d.yandex.cloud.cdn.v1.Resource\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cdn/v1/resources/{resource_id}\x12x\n\x04List\x12).yandex.cloud.cdn.v1.ListResourcesRequest\x1a*.yandex.cloud.cdn.v1.ListResourcesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/cdn/v1/resources\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.cdn.v1.CreateResourceRequest\x1a!.yandex.cloud.operation.Operation\"B\x82\xd3\xe4\x93\x02\x16\"\x11/cdn/v1/resources:\x01*\xb2\xd2*\"\n\x16\x43reateResourceMetadata\x12\x08Resource\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.cdn.v1.UpdateResourceRequest\x1a!.yandex.cloud.operation.Operation\"P\x82\xd3\xe4\x93\x02$2\x1f/cdn/v1/resources/{resource_id}:\x01*\xb2\xd2*\"\n\x16UpdateResourceMetadata\x12\x08Resource\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.cdn.v1.DeleteResourceRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02!*\x1f/cdn/v1/resources/{resource_id}\xb2\xd2*/\n\x16\x44\x65leteResourceMetadata\x12\x15google.protobuf.Empty\x12\x92\x01\n\x10GetProviderCName\x12,.yandex.cloud.cdn.v1.GetProviderCNameRequest\x1a-.yandex.cloud.cdn.v1.GetProviderCNameResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/cdn/v1/cname/{folder_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2.DESCRIPTOR,yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETRESOURCEREQUEST = _descriptor.Descriptor(
  name='GetResourceRequest',
  full_name='yandex.cloud.cdn.v1.GetResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.GetResourceRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=359,
)


_LISTRESOURCESREQUEST = _descriptor.Descriptor(
  name='ListResourcesRequest',
  full_name='yandex.cloud.cdn.v1.ListResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.ListResourcesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.cdn.v1.ListResourcesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.cdn.v1.ListResourcesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=478,
)


_LISTRESOURCESRESPONSE = _descriptor.Descriptor(
  name='ListResourcesResponse',
  full_name='yandex.cloud.cdn.v1.ListResourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.cdn.v1.ListResourcesResponse.resources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.cdn.v1.ListResourcesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=578,
)


_CREATERESOURCEREQUEST_ORIGIN = _descriptor.Descriptor(
  name='Origin',
  full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_group_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_source', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_source_params', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_source_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='origin_variant', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.Origin.origin_variant',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1033,
  serialized_end=1186,
)

_CREATERESOURCEREQUEST = _descriptor.Descriptor(
  name='CreateResourceRequest',
  full_name='yandex.cloud.cdn.v1.CreateResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cname', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.cname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.origin', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_hostnames', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.secondary_hostnames', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_protocol', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.origin_protocol', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.active', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_certificate', full_name='yandex.cloud.cdn.v1.CreateResourceRequest.ssl_certificate', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATERESOURCEREQUEST_ORIGIN, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=1186,
)


_RESOURCEORIGINPARAMS = _descriptor.Descriptor(
  name='ResourceOriginParams',
  full_name='yandex.cloud.cdn.v1.ResourceOriginParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.cdn.v1.ResourceOriginParams.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meta', full_name='yandex.cloud.cdn.v1.ResourceOriginParams.meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1188,
  serialized_end=1273,
)


_CREATERESOURCEMETADATA = _descriptor.Descriptor(
  name='CreateResourceMetadata',
  full_name='yandex.cloud.cdn.v1.CreateResourceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.CreateResourceMetadata.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1334,
)


_UPDATERESOURCEREQUEST = _descriptor.Descriptor(
  name='UpdateResourceRequest',
  full_name='yandex.cloud.cdn.v1.UpdateResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_group_id', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.origin_group_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_hostnames', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.secondary_hostnames', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.options', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_protocol', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.origin_protocol', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.active', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_certificate', full_name='yandex.cloud.cdn.v1.UpdateResourceRequest.ssl_certificate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1337,
  serialized_end=1748,
)


_UPDATERESOURCEMETADATA = _descriptor.Descriptor(
  name='UpdateResourceMetadata',
  full_name='yandex.cloud.cdn.v1.UpdateResourceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.UpdateResourceMetadata.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1809,
)


_DELETERESOURCEREQUEST = _descriptor.Descriptor(
  name='DeleteResourceRequest',
  full_name='yandex.cloud.cdn.v1.DeleteResourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.DeleteResourceRequest.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=1869,
)


_DELETERESOURCEMETADATA = _descriptor.Descriptor(
  name='DeleteResourceMetadata',
  full_name='yandex.cloud.cdn.v1.DeleteResourceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='yandex.cloud.cdn.v1.DeleteResourceMetadata.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1916,
)


_GETPROVIDERCNAMEREQUEST = _descriptor.Descriptor(
  name='GetProviderCNameRequest',
  full_name='yandex.cloud.cdn.v1.GetProviderCNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.GetProviderCNameRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1976,
)


_GETPROVIDERCNAMERESPONSE = _descriptor.Descriptor(
  name='GetProviderCNameResponse',
  full_name='yandex.cloud.cdn.v1.GetProviderCNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cname', full_name='yandex.cloud.cdn.v1.GetProviderCNameResponse.cname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.cdn.v1.GetProviderCNameResponse.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1978,
  serialized_end=2038,
)

_LISTRESOURCESRESPONSE.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCE
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source_params'].message_type = _RESOURCEORIGINPARAMS
_CREATERESOURCEREQUEST_ORIGIN.containing_type = _CREATERESOURCEREQUEST
_CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant'].fields.append(
  _CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_group_id'])
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_group_id'].containing_oneof = _CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant']
_CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant'].fields.append(
  _CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source'])
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source'].containing_oneof = _CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant']
_CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant'].fields.append(
  _CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source_params'])
_CREATERESOURCEREQUEST_ORIGIN.fields_by_name['origin_source_params'].containing_oneof = _CREATERESOURCEREQUEST_ORIGIN.oneofs_by_name['origin_variant']
_CREATERESOURCEREQUEST.fields_by_name['origin'].message_type = _CREATERESOURCEREQUEST_ORIGIN
_CREATERESOURCEREQUEST.fields_by_name['secondary_hostnames'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SECONDARYHOSTNAMES
_CREATERESOURCEREQUEST.fields_by_name['origin_protocol'].enum_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._ORIGINPROTOCOL
_CREATERESOURCEREQUEST.fields_by_name['active'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CREATERESOURCEREQUEST.fields_by_name['options'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCEOPTIONS
_CREATERESOURCEREQUEST.fields_by_name['ssl_certificate'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SSLTARGETCERTIFICATE
_RESOURCEORIGINPARAMS.fields_by_name['meta'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2._ORIGINMETA
_UPDATERESOURCEREQUEST.fields_by_name['origin_group_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_UPDATERESOURCEREQUEST.fields_by_name['secondary_hostnames'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SECONDARYHOSTNAMES
_UPDATERESOURCEREQUEST.fields_by_name['options'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCEOPTIONS
_UPDATERESOURCEREQUEST.fields_by_name['origin_protocol'].enum_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._ORIGINPROTOCOL
_UPDATERESOURCEREQUEST.fields_by_name['active'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_UPDATERESOURCEREQUEST.fields_by_name['ssl_certificate'].message_type = yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._SSLTARGETCERTIFICATE
DESCRIPTOR.message_types_by_name['GetResourceRequest'] = _GETRESOURCEREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesRequest'] = _LISTRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListResourcesResponse'] = _LISTRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateResourceRequest'] = _CREATERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['ResourceOriginParams'] = _RESOURCEORIGINPARAMS
DESCRIPTOR.message_types_by_name['CreateResourceMetadata'] = _CREATERESOURCEMETADATA
DESCRIPTOR.message_types_by_name['UpdateResourceRequest'] = _UPDATERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['UpdateResourceMetadata'] = _UPDATERESOURCEMETADATA
DESCRIPTOR.message_types_by_name['DeleteResourceRequest'] = _DELETERESOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResourceMetadata'] = _DELETERESOURCEMETADATA
DESCRIPTOR.message_types_by_name['GetProviderCNameRequest'] = _GETPROVIDERCNAMEREQUEST
DESCRIPTOR.message_types_by_name['GetProviderCNameResponse'] = _GETPROVIDERCNAMERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetResourceRequest = _reflection.GeneratedProtocolMessageType('GetResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetResourceRequest)
  })
_sym_db.RegisterMessage(GetResourceRequest)

ListResourcesRequest = _reflection.GeneratedProtocolMessageType('ListResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListResourcesRequest)
  })
_sym_db.RegisterMessage(ListResourcesRequest)

ListResourcesResponse = _reflection.GeneratedProtocolMessageType('ListResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRESOURCESRESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ListResourcesResponse)
  })
_sym_db.RegisterMessage(ListResourcesResponse)

CreateResourceRequest = _reflection.GeneratedProtocolMessageType('CreateResourceRequest', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _CREATERESOURCEREQUEST_ORIGIN,
    '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateResourceRequest.Origin)
    })
  ,
  'DESCRIPTOR' : _CREATERESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateResourceRequest)
  })
_sym_db.RegisterMessage(CreateResourceRequest)
_sym_db.RegisterMessage(CreateResourceRequest.Origin)

ResourceOriginParams = _reflection.GeneratedProtocolMessageType('ResourceOriginParams', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEORIGINPARAMS,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.ResourceOriginParams)
  })
_sym_db.RegisterMessage(ResourceOriginParams)

CreateResourceMetadata = _reflection.GeneratedProtocolMessageType('CreateResourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.CreateResourceMetadata)
  })
_sym_db.RegisterMessage(CreateResourceMetadata)

UpdateResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateResourceRequest)
  })
_sym_db.RegisterMessage(UpdateResourceRequest)

UpdateResourceMetadata = _reflection.GeneratedProtocolMessageType('UpdateResourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.UpdateResourceMetadata)
  })
_sym_db.RegisterMessage(UpdateResourceMetadata)

DeleteResourceRequest = _reflection.GeneratedProtocolMessageType('DeleteResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteResourceRequest)
  })
_sym_db.RegisterMessage(DeleteResourceRequest)

DeleteResourceMetadata = _reflection.GeneratedProtocolMessageType('DeleteResourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCEMETADATA,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.DeleteResourceMetadata)
  })
_sym_db.RegisterMessage(DeleteResourceMetadata)

GetProviderCNameRequest = _reflection.GeneratedProtocolMessageType('GetProviderCNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROVIDERCNAMEREQUEST,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetProviderCNameRequest)
  })
_sym_db.RegisterMessage(GetProviderCNameRequest)

GetProviderCNameResponse = _reflection.GeneratedProtocolMessageType('GetProviderCNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROVIDERCNAMERESPONSE,
  '__module__' : 'yandex.cloud.cdn.v1.resource_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.cdn.v1.GetProviderCNameResponse)
  })
_sym_db.RegisterMessage(GetProviderCNameResponse)


DESCRIPTOR._options = None
_GETRESOURCEREQUEST.fields_by_name['resource_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['folder_id']._options = None
_LISTRESOURCESREQUEST.fields_by_name['page_size']._options = None
_LISTRESOURCESREQUEST.fields_by_name['page_token']._options = None
_CREATERESOURCEREQUEST.fields_by_name['folder_id']._options = None
_CREATERESOURCEREQUEST.fields_by_name['cname']._options = None
_CREATERESOURCEREQUEST.fields_by_name['origin']._options = None
_CREATERESOURCEMETADATA.fields_by_name['resource_id']._options = None
_UPDATERESOURCEREQUEST.fields_by_name['resource_id']._options = None
_UPDATERESOURCEMETADATA.fields_by_name['resource_id']._options = None
_DELETERESOURCEREQUEST.fields_by_name['resource_id']._options = None
_GETPROVIDERCNAMEREQUEST.fields_by_name['folder_id']._options = None

_RESOURCESERVICE = _descriptor.ServiceDescriptor(
  name='ResourceService',
  full_name='yandex.cloud.cdn.v1.ResourceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2041,
  serialized_end=2961,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.cdn.v1.ResourceService.Get',
    index=0,
    containing_service=None,
    input_type=_GETRESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2._RESOURCE,
    serialized_options=b'\202\323\344\223\002!\022\037/cdn/v1/resources/{resource_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.cdn.v1.ResourceService.List',
    index=1,
    containing_service=None,
    input_type=_LISTRESOURCESREQUEST,
    output_type=_LISTRESOURCESRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/cdn/v1/resources',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.cdn.v1.ResourceService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATERESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/cdn/v1/resources:\001*\262\322*\"\n\026CreateResourceMetadata\022\010Resource',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.cdn.v1.ResourceService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATERESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$2\037/cdn/v1/resources/{resource_id}:\001*\262\322*\"\n\026UpdateResourceMetadata\022\010Resource',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.cdn.v1.ResourceService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETERESOURCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!*\037/cdn/v1/resources/{resource_id}\262\322*/\n\026DeleteResourceMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProviderCName',
    full_name='yandex.cloud.cdn.v1.ResourceService.GetProviderCName',
    index=5,
    containing_service=None,
    input_type=_GETPROVIDERCNAMEREQUEST,
    output_type=_GETPROVIDERCNAMERESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/cdn/v1/cname/{folder_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RESOURCESERVICE)

DESCRIPTOR.services_by_name['ResourceService'] = _RESOURCESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/devices/v1/registry_data_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iot/devices/v1/registry_data_service.proto',
  package='yandex.cloud.iot.devices.v1',
  syntax='proto3',
  serialized_options=b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/iot/devices/v1/registry_data_service.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"z\n\x1aPublishRegistryDataRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05topic\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1a\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x0c\x8a\xc8\x31\x08<=262144\"\x1d\n\x1bPublishRegistryDataResponse2\xd1\x01\n\x13RegistryDataService\x12\xb9\x01\n\x07Publish\x12\x37.yandex.cloud.iot.devices.v1.PublishRegistryDataRequest\x1a\x38.yandex.cloud.iot.devices.v1.PublishRegistryDataResponse\";\x82\xd3\xe4\x93\x02\x35\"0/iot-devices/v1/registries/{registry_id}/publish:\x01*Bj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_PUBLISHREGISTRYDATAREQUEST = _descriptor.Descriptor(
  name='PublishRegistryDataRequest',
  full_name='yandex.cloud.iot.devices.v1.PublishRegistryDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.iot.devices.v1.PublishRegistryDataRequest.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='yandex.cloud.iot.devices.v1.PublishRegistryDataRequest.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.iot.devices.v1.PublishRegistryDataRequest.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\010<=262144', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=271,
)


_PUBLISHREGISTRYDATARESPONSE = _descriptor.Descriptor(
  name='PublishRegistryDataResponse',
  full_name='yandex.cloud.iot.devices.v1.PublishRegistryDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=302,
)

DESCRIPTOR.message_types_by_name['PublishRegistryDataRequest'] = _PUBLISHREGISTRYDATAREQUEST
DESCRIPTOR.message_types_by_name['PublishRegistryDataResponse'] = _PUBLISHREGISTRYDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PublishRegistryDataRequest = _reflection.GeneratedProtocolMessageType('PublishRegistryDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHREGISTRYDATAREQUEST,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_data_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.PublishRegistryDataRequest)
  })
_sym_db.RegisterMessage(PublishRegistryDataRequest)

PublishRegistryDataResponse = _reflection.GeneratedProtocolMessageType('PublishRegistryDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHREGISTRYDATARESPONSE,
  '__module__' : 'yandex.cloud.iot.devices.v1.registry_data_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.PublishRegistryDataResponse)
  })
_sym_db.RegisterMessage(PublishRegistryDataResponse)


DESCRIPTOR._options = None
_PUBLISHREGISTRYDATAREQUEST.fields_by_name['registry_id']._options = None
_PUBLISHREGISTRYDATAREQUEST.fields_by_name['topic']._options = None
_PUBLISHREGISTRYDATAREQUEST.fields_by_name['data']._options = None

_REGISTRYDATASERVICE = _descriptor.ServiceDescriptor(
  name='RegistryDataService',
  full_name='yandex.cloud.iot.devices.v1.RegistryDataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=305,
  serialized_end=514,
  methods=[
  _descriptor.MethodDescriptor(
    name='Publish',
    full_name='yandex.cloud.iot.devices.v1.RegistryDataService.Publish',
    index=0,
    containing_service=None,
    input_type=_PUBLISHREGISTRYDATAREQUEST,
    output_type=_PUBLISHREGISTRYDATARESPONSE,
    serialized_options=b'\202\323\344\223\0025\"0/iot-devices/v1/registries/{registry_id}/publish:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REGISTRYDATASERVICE)

DESCRIPTOR.services_by_name['RegistryDataService'] = _REGISTRYDATASERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1/maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mysql/v1/maintenance.proto',
  package='yandex.cloud.mdb.mysql.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysql',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+yandex/cloud/mdb/mysql/v1/maintenance.proto\x12\x19yandex.cloud.mdb.mysql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xc4\x01\n\x11MaintenanceWindow\x12\x46\n\x07\x61nytime\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.mdb.mysql.v1.AnytimeMaintenanceWindowH\x00\x12W\n\x19weekly_maintenance_window\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindowH\x00\x42\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"\x1a\n\x18\x41nytimeMaintenanceWindow\"\xde\x01\n\x17WeeklyMaintenanceWindow\x12G\n\x03\x64\x61y\x18\x01 \x01(\x0e\x32:.yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindow.WeekDay\x12\x16\n\x04hour\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x31-24\"b\n\x07WeekDay\x12\x18\n\x14WEEK_DAY_UNSPECIFIED\x10\x00\x12\x07\n\x03MON\x10\x01\x12\x07\n\x03TUE\x10\x02\x12\x07\n\x03WED\x10\x03\x12\x07\n\x03THU\x10\x04\x12\x07\n\x03\x46RI\x10\x05\x12\x07\n\x03SAT\x10\x06\x12\x07\n\x03SUN\x10\x07\"b\n\x14MaintenanceOperation\x12\x17\n\x04info\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x31\n\rdelayed_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBd\n\x1dyandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysqlb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_WEEKLYMAINTENANCEWINDOW_WEEKDAY = _descriptor.EnumDescriptor(
  name='WeekDay',
  full_name='yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindow.WeekDay',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEEK_DAY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THU', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRI', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=490,
  serialized_end=588,
)
_sym_db.RegisterEnumDescriptor(_WEEKLYMAINTENANCEWINDOW_WEEKDAY)


_MAINTENANCEWINDOW = _descriptor.Descriptor(
  name='MaintenanceWindow',
  full_name='yandex.cloud.mdb.mysql.v1.MaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anytime', full_name='yandex.cloud.mdb.mysql.v1.MaintenanceWindow.anytime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weekly_maintenance_window', full_name='yandex.cloud.mdb.mysql.v1.MaintenanceWindow.weekly_maintenance_window', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='policy', full_name='yandex.cloud.mdb.mysql.v1.MaintenanceWindow.policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=139,
  serialized_end=335,
)


_ANYTIMEMAINTENANCEWINDOW = _descriptor.Descriptor(
  name='AnytimeMaintenanceWindow',
  full_name='yandex.cloud.mdb.mysql.v1.AnytimeMaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=363,
)


_WEEKLYMAINTENANCEWINDOW = _descriptor.Descriptor(
  name='WeeklyMaintenanceWindow',
  full_name='yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='day', full_name='yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindow.day', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindow.hour', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0041-24', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WEEKLYMAINTENANCEWINDOW_WEEKDAY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=588,
)


_MAINTENANCEOPERATION = _descriptor.Descriptor(
  name='MaintenanceOperation',
  full_name='yandex.cloud.mdb.mysql.v1.MaintenanceOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='yandex.cloud.mdb.mysql.v1.MaintenanceOperation.info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delayed_until', full_name='yandex.cloud.mdb.mysql.v1.MaintenanceOperation.delayed_until', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=688,
)

_MAINTENANCEWINDOW.fields_by_name['anytime'].message_type = _ANYTIMEMAINTENANCEWINDOW
_MAINTENANCEWINDOW.fields_by_name['weekly_maintenance_window'].message_type = _WEEKLYMAINTENANCEWINDOW
_MAINTENANCEWINDOW.oneofs_by_name['policy'].fields.append(
  _MAINTENANCEWINDOW.fields_by_name['anytime'])
_MAINTENANCEWINDOW.fields_by_name['anytime'].containing_oneof = _MAINTENANCEWINDOW.oneofs_by_name['policy']
_MAINTENANCEWINDOW.oneofs_by_name['policy'].fields.append(
  _MAINTENANCEWINDOW.fields_by_name['weekly_maintenance_window'])
_MAINTENANCEWINDOW.fields_by_name['weekly_maintenance_window'].containing_oneof = _MAINTENANCEWINDOW.oneofs_by_name['policy']
_WEEKLYMAINTENANCEWINDOW.fields_by_name['day'].enum_type = _WEEKLYMAINTENANCEWINDOW_WEEKDAY
_WEEKLYMAINTENANCEWINDOW_WEEKDAY.containing_type = _WEEKLYMAINTENANCEWINDOW
_MAINTENANCEOPERATION.fields_by_name['delayed_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['MaintenanceWindow'] = _MAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['AnytimeMaintenanceWindow'] = _ANYTIMEMAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['WeeklyMaintenanceWindow'] = _WEEKLYMAINTENANCEWINDOW
DESCRIPTOR.message_types_by_name['MaintenanceOperation'] = _MAINTENANCEOPERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MaintenanceWindow = _reflection.GeneratedProtocolMessageType('MaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.mdb.mysql.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1.MaintenanceWindow)
  })
_sym_db.RegisterMessage(MaintenanceWindow)

AnytimeMaintenanceWindow = _reflection.GeneratedProtocolMessageType('AnytimeMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _ANYTIMEMAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.mdb.mysql.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1.AnytimeMaintenanceWindow)
  })
_sym_db.RegisterMessage(AnytimeMaintenanceWindow)

WeeklyMaintenanceWindow = _reflection.GeneratedProtocolMessageType('WeeklyMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _WEEKLYMAINTENANCEWINDOW,
  '__module__' : 'yandex.cloud.mdb.mysql.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1.WeeklyMaintenanceWindow)
  })
_sym_db.RegisterMessage(WeeklyMaintenanceWindow)

MaintenanceOperation = _reflection.GeneratedProtocolMessageType('MaintenanceOperation', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEOPERATION,
  '__module__' : 'yandex.cloud.mdb.mysql.v1.maintenance_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mysql.v1.MaintenanceOperation)
  })
_sym_db.RegisterMessage(MaintenanceOperation)


DESCRIPTOR._options = None
_MAINTENANCEWINDOW.oneofs_by_name['policy']._options = None
_WEEKLYMAINTENANCEWINDOW.fields_by_name['hour']._options = None
_MAINTENANCEOPERATION.fields_by_name['info']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/greenplum/v1/config.proto',
  package='yandex.cloud.mdb.greenplum.v1',
  syntax='proto3',
  serialized_options=b'\n!yandex.cloud.api.mdb.greenplum.v1B\004GPCFZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\x9e\x01\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12G\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet\"\xa0\x01\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\x12H\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet\"\xb5\x02\n\x15GreenplumMasterConfig\x12P\n\tlog_level\x18\x01 \x01(\x0e\x32=.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.LogLevel\x12\x34\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\x08timezone\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"d\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x0f\n\x0bINFORMATION\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x87\x02\n\x16GreenplumSegmentConfig\x12Q\n\tlog_level\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.LogLevel\x12\x34\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"d\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x0f\n\x0bINFORMATION\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x89\x02\n\x18GreenplumMasterConfigSet\x12T\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigB\x04\xe8\xc7\x31\x01\x12I\n\x0buser_config\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig\x12L\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig\"\x8d\x02\n\x19GreenplumSegmentConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigBv\n!yandex.cloud.api.mdb.greenplum.v1B\x04GPCFZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_GREENPLUMMASTERCONFIG_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFORMATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=756,
  serialized_end=856,
)
_sym_db.RegisterEnumDescriptor(_GREENPLUMMASTERCONFIG_LOGLEVEL)

_GREENPLUMSEGMENTCONFIG_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFORMATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=756,
  serialized_end=856,
)
_sym_db.RegisterEnumDescriptor(_GREENPLUMSEGMENTCONFIG_LOGLEVEL)


_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='yandex.cloud.mdb.greenplum.v1.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_preset_id', full_name='yandex.cloud.mdb.greenplum.v1.Resources.resource_preset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_size', full_name='yandex.cloud.mdb.greenplum.v1.Resources.disk_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_type_id', full_name='yandex.cloud.mdb.greenplum.v1.Resources.disk_type_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=220,
)


_MASTERSUBCLUSTERCONFIG = _descriptor.Descriptor(
  name='MasterSubclusterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=381,
)


_SEGMENTSUBCLUSTERCONFIG = _descriptor.Descriptor(
  name='SegmentSubclusterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=544,
)


_GREENPLUMMASTERCONFIG = _descriptor.Descriptor(
  name='GreenplumMasterConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_level', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.log_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig.timezone', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GREENPLUMMASTERCONFIG_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=856,
)


_GREENPLUMSEGMENTCONFIG = _descriptor.Descriptor(
  name='GreenplumSegmentConfig',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_level', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.log_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connections', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig.max_connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GREENPLUMSEGMENTCONFIG_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=1122,
)


_GREENPLUMMASTERCONFIGSET = _descriptor.Descriptor(
  name='GreenplumMasterConfigSet',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1390,
)


_GREENPLUMSEGMENTCONFIGSET = _descriptor.Descriptor(
  name='GreenplumSegmentConfigSet',
  full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1662,
)

_MASTERSUBCLUSTERCONFIG.fields_by_name['resources'].message_type = _RESOURCES
_MASTERSUBCLUSTERCONFIG.fields_by_name['config'].message_type = _GREENPLUMMASTERCONFIGSET
_SEGMENTSUBCLUSTERCONFIG.fields_by_name['resources'].message_type = _RESOURCES
_SEGMENTSUBCLUSTERCONFIG.fields_by_name['config'].message_type = _GREENPLUMSEGMENTCONFIGSET
_GREENPLUMMASTERCONFIG.fields_by_name['log_level'].enum_type = _GREENPLUMMASTERCONFIG_LOGLEVEL
_GREENPLUMMASTERCONFIG.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMMASTERCONFIG.fields_by_name['timezone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GREENPLUMMASTERCONFIG_LOGLEVEL.containing_type = _GREENPLUMMASTERCONFIG
_GREENPLUMSEGMENTCONFIG.fields_by_name['log_level'].enum_type = _GREENPLUMSEGMENTCONFIG_LOGLEVEL
_GREENPLUMSEGMENTCONFIG.fields_by_name['max_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GREENPLUMSEGMENTCONFIG_LOGLEVEL.containing_type = _GREENPLUMSEGMENTCONFIG
_GREENPLUMMASTERCONFIGSET.fields_by_name['effective_config'].message_type = _GREENPLUMMASTERCONFIG
_GREENPLUMMASTERCONFIGSET.fields_by_name['user_config'].message_type = _GREENPLUMMASTERCONFIG
_GREENPLUMMASTERCONFIGSET.fields_by_name['default_config'].message_type = _GREENPLUMMASTERCONFIG
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['effective_config'].message_type = _GREENPLUMSEGMENTCONFIG
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['user_config'].message_type = _GREENPLUMSEGMENTCONFIG
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['default_config'].message_type = _GREENPLUMSEGMENTCONFIG
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
DESCRIPTOR.message_types_by_name['MasterSubclusterConfig'] = _MASTERSUBCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['SegmentSubclusterConfig'] = _SEGMENTSUBCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['GreenplumMasterConfig'] = _GREENPLUMMASTERCONFIG
DESCRIPTOR.message_types_by_name['GreenplumSegmentConfig'] = _GREENPLUMSEGMENTCONFIG
DESCRIPTOR.message_types_by_name['GreenplumMasterConfigSet'] = _GREENPLUMMASTERCONFIGSET
DESCRIPTOR.message_types_by_name['GreenplumSegmentConfigSet'] = _GREENPLUMSEGMENTCONFIGSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.Resources)
  })
_sym_db.RegisterMessage(Resources)

MasterSubclusterConfig = _reflection.GeneratedProtocolMessageType('MasterSubclusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _MASTERSUBCLUSTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.MasterSubclusterConfig)
  })
_sym_db.RegisterMessage(MasterSubclusterConfig)

SegmentSubclusterConfig = _reflection.GeneratedProtocolMessageType('SegmentSubclusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTSUBCLUSTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.SegmentSubclusterConfig)
  })
_sym_db.RegisterMessage(SegmentSubclusterConfig)

GreenplumMasterConfig = _reflection.GeneratedProtocolMessageType('GreenplumMasterConfig', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMMASTERCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfig)
  })
_sym_db.RegisterMessage(GreenplumMasterConfig)

GreenplumSegmentConfig = _reflection.GeneratedProtocolMessageType('GreenplumSegmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMSEGMENTCONFIG,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfig)
  })
_sym_db.RegisterMessage(GreenplumSegmentConfig)

GreenplumMasterConfigSet = _reflection.GeneratedProtocolMessageType('GreenplumMasterConfigSet', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMMASTERCONFIGSET,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumMasterConfigSet)
  })
_sym_db.RegisterMessage(GreenplumMasterConfigSet)

GreenplumSegmentConfigSet = _reflection.GeneratedProtocolMessageType('GreenplumSegmentConfigSet', (_message.Message,), {
  'DESCRIPTOR' : _GREENPLUMSEGMENTCONFIGSET,
  '__module__' : 'yandex.cloud.mdb.greenplum.v1.config_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.greenplum.v1.GreenplumSegmentConfigSet)
  })
_sym_db.RegisterMessage(GreenplumSegmentConfigSet)


DESCRIPTOR._options = None
_GREENPLUMMASTERCONFIGSET.fields_by_name['effective_config']._options = None
_GREENPLUMSEGMENTCONFIGSET.fields_by_name['effective_config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/devices/v1/device_data_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iot/devices/v1/device_data_service.proto',
  package='yandex.cloud.iot.devices.v1',
  syntax='proto3',
  serialized_options=b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/iot/devices/v1/device_data_service.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"v\n\x18PublishDeviceDataRequest\x12\x1f\n\tdevice_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05topic\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1a\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x0c\x8a\xc8\x31\x08<=262144\"\x1b\n\x19PublishDeviceDataResponse2\xc6\x01\n\x11\x44\x65viceDataService\x12\xb0\x01\n\x07Publish\x12\x35.yandex.cloud.iot.devices.v1.PublishDeviceDataRequest\x1a\x36.yandex.cloud.iot.devices.v1.PublishDeviceDataResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/iot-devices/v1/devices/{device_id}/publish:\x01*Bj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_PUBLISHDEVICEDATAREQUEST = _descriptor.Descriptor(
  name='PublishDeviceDataRequest',
  full_name='yandex.cloud.iot.devices.v1.PublishDeviceDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='yandex.cloud.iot.devices.v1.PublishDeviceDataRequest.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='yandex.cloud.iot.devices.v1.PublishDeviceDataRequest.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.iot.devices.v1.PublishDeviceDataRequest.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\010<=262144', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=265,
)


_PUBLISHDEVICEDATARESPONSE = _descriptor.Descriptor(
  name='PublishDeviceDataResponse',
  full_name='yandex.cloud.iot.devices.v1.PublishDeviceDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=294,
)

DESCRIPTOR.message_types_by_name['PublishDeviceDataRequest'] = _PUBLISHDEVICEDATAREQUEST
DESCRIPTOR.message_types_by_name['PublishDeviceDataResponse'] = _PUBLISHDEVICEDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PublishDeviceDataRequest = _reflection.GeneratedProtocolMessageType('PublishDeviceDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDEVICEDATAREQUEST,
  '__module__' : 'yandex.cloud.iot.devices.v1.device_data_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.PublishDeviceDataRequest)
  })
_sym_db.RegisterMessage(PublishDeviceDataRequest)

PublishDeviceDataResponse = _reflection.GeneratedProtocolMessageType('PublishDeviceDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDEVICEDATARESPONSE,
  '__module__' : 'yandex.cloud.iot.devices.v1.device_data_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.devices.v1.PublishDeviceDataResponse)
  })
_sym_db.RegisterMessage(PublishDeviceDataResponse)


DESCRIPTOR._options = None
_PUBLISHDEVICEDATAREQUEST.fields_by_name['device_id']._options = None
_PUBLISHDEVICEDATAREQUEST.fields_by_name['topic']._options = None
_PUBLISHDEVICEDATAREQUEST.fields_by_name['data']._options = None

_DEVICEDATASERVICE = _descriptor.ServiceDescriptor(
  name='DeviceDataService',
  full_name='yandex.cloud.iot.devices.v1.DeviceDataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=297,
  serialized_end=495,
  methods=[
  _descriptor.MethodDescriptor(
    name='Publish',
    full_name='yandex.cloud.iot.devices.v1.DeviceDataService.Publish',
    index=0,
    containing_service=None,
    input_type=_PUBLISHDEVICEDATAREQUEST,
    output_type=_PUBLISHDEVICEDATARESPONSE,
    serialized_options=b'\202\323\344\223\0020\"+/iot-devices/v1/devices/{device_id}/publish:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEVICEDATASERVICE)

DESCRIPTOR.services_by_name['DeviceDataService'] = _DEVICEDATASERVICE

# @@protoc_insertion_point(module_scope)
